function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { clone, take, isEqual, set, dropRight, concat, last, tail } from 'lodash';
/**
 * Menu is container component which contains MenuItems
 * @category containers
 * @component Menu
 * @variations collab-ui-react
 */

var Menu =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Menu, _React$Component);

  function Menu() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      menuIndex: []
    }, _this.getChildContext = function () {
      return {
        handleClick: function handleClick(menuItemIndex, menuItem, e) {
          return _this.handleClick(menuItemIndex, menuItem, e);
        },
        handleKeyDown: function handleKeyDown(menuItemIndex, menuItem, e) {
          return _this.handleKeyDown(menuItemIndex, menuItem, e);
        }
      };
    }, _this.handleClick = function (menuItemIndex, menuItem, e) {
      var onSelect = _this.props.onSelect;

      if (onSelect) {
        onSelect(e, menuItemIndex, menuItem);
      }

      _this.setState({
        menuIndex: menuItem.props.subMenu ? concat(menuItemIndex, _this.getNewIndex(-1, 1, menuItem.props.subMenu)) : [menuItemIndex[0]]
      });
    }, _this.getNewIndex = function (currentIndex, change, siblings) {
      var getPossibleIndex = function getPossibleIndex() {
        var length = siblings.length - 1;

        if (currentIndex + change < 0) {
          return length;
        } else if (currentIndex + change > length) {
          return 0;
        }

        return currentIndex + change;
      };

      var possibleIndex = getPossibleIndex();
      var potentialTarget = React.Children.toArray(siblings)[possibleIndex];
      return potentialTarget.props.disabled || potentialTarget.props.isHeader ? _this.getNewIndex(possibleIndex, change, siblings) : possibleIndex;
    }, _this.handleKeyDown = function (idx, menuItem, e) {
      var menuIndex = _this.state.menuIndex;
      var subMenu = menuItem.props.subMenu;
      var _this$props = _this.props,
          children = _this$props.children,
          onSelect = _this$props.onSelect;

      var getSiblings = function getSiblings(idx, menuItems) {
        if (menuItems === void 0) {
          menuItems = children;
        }

        if (idx.length === 1) {
          return menuItems;
        }

        return getSiblings(tail(idx), menuItems[idx[0]].props.subMenu);
      };

      var clickEvent;
      var tgt = e.currentTarget;
      var flag = false;

      switch (e.which) {
        case 32:
        case 13:
          try {
            clickEvent = new MouseEvent('click', {
              view: window,
              bubbles: true,
              cancelable: true
            });
          } catch (err) {
            if (document.createEvent) {
              // DOM Level 3 for IE 9+
              clickEvent = document.createEvent('MouseEvents');
              clickEvent.initEvent('click', true, true);
            }
          }

          tgt.dispatchEvent(clickEvent);
          flag = true;
          break;

        case 38:
          _this.setState({
            menuIndex: set(clone(menuIndex), menuIndex.length - 1, _this.getNewIndex(last(idx), -1, getSiblings(idx)))
          });

          flag = true;
          break;

        case 40:
          _this.setState({
            menuIndex: set(clone(menuIndex), menuIndex.length - 1, _this.getNewIndex(last(idx), 1, getSiblings(idx)))
          });

          flag = true;
          break;

        case 39:
          //right
          subMenu && _this.setState({
            menuIndex: concat(menuIndex, _this.getNewIndex(-1, 1, subMenu))
          }, function () {
            return onSelect && onSelect(e, menuIndex, menuItem);
          });
          flag = true;
          break;

        case 37:
          //left
          menuIndex.length - 1 && _this.setState({
            menuIndex: dropRight(menuIndex)
          });
          flag = true;
          break;

        default:
          break;
      }

      if (flag) {
        e.stopPropagation();
        e.preventDefault();
      }
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = Menu.prototype;

  _proto.componentWillMount = function componentWillMount() {
    var children = this.props.children;
    this.setState({
      menuIndex: [this.getNewIndex(-1, 1, React.Children.toArray(children))]
    });
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props2 = this.props,
        children = _this$props2.children,
        className = _this$props2.className,
        ariaLabel = _this$props2.ariaLabel;

    var setMenuItems = function setMenuItems(menuList, currentItemIndex) {
      if (currentItemIndex === void 0) {
        currentItemIndex = [];
      }

      var menuItems = React.Children.toArray(menuList).map(function (child, idx) {
        if (child.type.displayName !== 'MenuItem') {
          throw new Error('child elements and subMenu items should be MenuItem');
        }

        var menuItemIndex = currentItemIndex.concat(idx);
        var _child$props = child.props,
            subMenu = _child$props.subMenu,
            disabled = _child$props.disabled;
        var menuIndex = _this2.state.menuIndex;
        var focus = isEqual(menuIndex, menuItemIndex);
        var isOpen = isEqual(take(menuIndex, menuItemIndex.length), menuItemIndex) && menuIndex.length !== menuItemIndex.length;
        return React.cloneElement(child, {
          subMenu: subMenu && setMenuItems(subMenu, menuItemIndex),
          index: menuItemIndex,
          focus: focus,
          isOpen: isOpen
        });
      });
      return menuItems;
    };

    return React.createElement("div", {
      className: 'cui-menu' + ("" + (className && " " + className || '')),
      "aria-label": ariaLabel,
      role: "menubar"
    }, setMenuItems(children));
  };

  return Menu;
}(React.Component);

Menu.displayName = 'Menu';
Menu.childContextTypes = {
  handleClick: PropTypes.func,
  handleKeyDown: PropTypes.func
};
export { Menu as default };
Menu.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  onSelect: PropTypes.func,
  ariaLabel: PropTypes.string
};
Menu.defaultProps = {
  children: null,
  className: '',
  onSelect: null,
  ariaLabel: ''
};
/**
* @name Menu with Popover
*
* @category containers
* @component menu
* @section default
*
* @js
*
import { MenuItem, Button, Popover } from '@collab-ui/react';

export default class MenuDefault extends React.PureComponent {
  render() {
    const submenu1 = [
      <MenuItem key="0" isHeader>Set Do Not Disturb:</MenuItem>,
      <MenuItem key="1" disabled>1 hour</MenuItem>,
      <MenuItem key="2">5 hour</MenuItem>,
      <MenuItem key="3">8 hour</MenuItem>
    ];
    const submenu2 = [<MenuItem key="0">English</MenuItem>, <MenuItem key="1">Spanish</MenuItem>];
    const popoverContent = (
      <Menu>
        <MenuItem
          key="0"
          selectedValue="Out of office until 2:00pm"
          subMenu={submenu1}
        >
          Status
        </MenuItem>
        <MenuItem
          key="1"
          subMenu={submenu2}
          selectedValue="English"
        >
          Language
        </MenuItem>
        <MenuItem key="2">
          Settings
        </MenuItem>
      </Menu>
    );
    return(
      <Popover content={popoverContent} popoverTrigger="Click" direction="bottom-center">
        <Button>Show Menu</Button>
      </Popover>
    );
  }
}
**/

/**
* @name Customized menu with EventOverlay
*
* @category containers
* @component menu
* @section custom-menu
*
* @js
*
 import { MenuItem, Button, EventOverlay } from '@collab-ui/react';

 export default class CustomMenu extends React.PureComponent {
  state = {
    isOpen: false
  };

  onSelect = (e, idx, menuItem) => {
    if(menuItem.props.shouldCloseMenu) {
      this.setState({ isOpen: false });
    }
  };

  render() {
    const { isOpen } = this.state;
    const submenu1 = [
      <MenuItem key="0" isHeader>Set Do Not Disturb:</MenuItem>,
      <MenuItem key="1" disabled>1 hour</MenuItem>,
      <MenuItem key="2">5 hour</MenuItem>,
      <MenuItem key="3">8 hour</MenuItem>
    ];
    const submenu2 = [<MenuItem key="0" shouldCloseMenu>English</MenuItem>, <MenuItem key="1" shouldCloseMenu>Spanish</MenuItem>];
    const popoverContent = (
      <Menu onSelect={this.onSelect}>
        <MenuItem key="0" subMenu={submenu1}>
          Status
        </MenuItem>
        <MenuItem key="1" subMenu={submenu2}>
          Language
        </MenuItem>
        <MenuItem key="2" shouldCloseMenu>
          Settings
        </MenuItem>
      </Menu>
    );
    return(
      <div>
        <Button
          onClick={() => this.setState({ isOpen: !this.state.isOpen})}
          ref={ref => this.anchor = ref}
        >
          Show Menu
        </Button>
        <EventOverlay
          allowClickAway
          isOpen={isOpen}
          showArrow
          close={(e) => this.setState({ isOpen: false })}
          anchorNode={this.anchor}
        >
          {popoverContent}
        </EventOverlay>
        <br></br>
        <br></br>
        <br></br>
        <br></br>
      </div>
    );
  }
}
 **/