"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

var Avatar =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Avatar, _React$Component);

  function Avatar() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      isImageLoaded: false,
      isImageErrored: false
    }, _this.handleImgError = function () {
      _this.setState({
        isImageErrored: true
      });
    }, _this.handleImgLoaded = function () {
      _this.setState({
        isImageLoaded: true
      });
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = Avatar.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        alt = _this$props.alt,
        backgroundColor = _this$props.backgroundColor,
        color = _this$props.color,
        hideDefaultTooltip = _this$props.hideDefaultTooltip,
        isOverview = _this$props.isOverview,
        src = _this$props.src,
        title = _this$props.title,
        type = _this$props.type,
        size = _this$props.size,
        className = _this$props.className,
        icon = _this$props.icon,
        failureBadge = _this$props.failureBadge;
    var _this$state = this.state,
        isImageLoaded = _this$state.isImageLoaded,
        isImageErrored = _this$state.isImageErrored;

    var getInitials = function getInitials() {
      var letters = [];
      var words = title.trim().split(/ +/);
      var repeatTimes = Math.min(type === 'group' && 1 || 2, words.length);

      for (var i = 0; i < repeatTimes; i++) {
        letters.push(String.fromCodePoint(words[i].codePointAt(0)));
      }

      return letters.join('');
    };

    var getIcon = function getIcon() {
      if (icon.type.displayName === 'Icon') {
        return _react.default.createElement("span", {
          className: 'cui-avatar__icon' + ("" + (isOverview ? ' cui-avatar__icon--overview' : '')),
          style: {
            backgroundColor: backgroundColor,
            color: color
          }
        }, icon);
      }

      throw new Error('Icon prop should be a component of type Icon');
    };

    var getLetter = function getLetter() {
      return _react.default.createElement("span", {
        key: "letter",
        className: 'cui-avatar__letter' + ("" + (isImageLoaded && " cui-avatar__img--hidden" || '')),
        style: {
          backgroundColor: backgroundColor,
          color: color
        }
      }, getInitials());
    };

    var getChildren = function getChildren() {
      // image src is present and image has not yet errored
      if (src && !isImageErrored) {
        var imgChildren = []; // image is not loaded and title is provided

        if (title && !isImageLoaded) {
          imgChildren.push(getLetter());
        }

        imgChildren.push(_react.default.createElement("img", {
          key: "image",
          alt: alt,
          className: "cui-avatar__img" + ("" + (!isImageLoaded && " cui-avatar__img--hidden" || '')),
          draggable: false,
          onError: _this2.handleImgError,
          onLoad: _this2.handleImgLoaded,
          src: src
        }));
        return imgChildren;
      } else if (icon) {
        return getIcon();
      } else if (title) {
        return getLetter();
      }
    };

    return _react.default.createElement("div", {
      className: 'cui-avatar' + ("" + (type && " cui-avatar--" + type || '')) + ("" + (size && " cui-avatar--" + size || '')) + ("" + (className && " " + className || '')),
      title: !hideDefaultTooltip ? title : ''
    }, getChildren(), type === 'typing' && _react.default.createElement(_.Loading, null), failureBadge && _react.default.createElement("span", {
      className: "cui-avatar__failure-badge"
    }));
  };

  return Avatar;
}(_react.default.Component);

exports.default = Avatar;
Avatar.displayName = 'Avatar';
Avatar.propTypes = {
  alt: _propTypes.default.string,
  backgroundColor: _propTypes.default.string,
  color: _propTypes.default.string,
  className: _propTypes.default.string,
  hideDefaultTooltip: _propTypes.default.bool,
  isOverview: _propTypes.default.bool,
  size: _propTypes.default.oneOf(['xsmall', 'small', 'medium', 'large', 'xlarge', 18, 24, 28, 36, 40, 44, 52, 72, 80, 84]),
  src: _propTypes.default.string,
  title: _propTypes.default.string,
  type: _propTypes.default.oneOf(['', 'active', 'inactive', 'dnd', 'ooo', 'group', 'typing', 'bot']),
  icon: _propTypes.default.element,
  failureBadge: _propTypes.default.bool
};
Avatar.defaultProps = {
  alt: '',
  backgroundColor: '',
  className: null,
  color: '',
  hideDefaultTooltip: false,
  isOverview: false,
  size: 'medium',
  src: null,
  title: null,
  type: '',
  icon: null,
  failureBadge: false
};
/**
* @name Different sizes of avatar
*
* @category communication
* @component avatar
* @section default
*
* @js
*

 export default class AvatarDefault extends React.PureComponent {
  render() {
    return (
      <div className='row'>
        <div className="example-spacing">
          <p><span className="h3">size=(18)</span></p>
          <div><Avatar size={18} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(24)</span></p>
          <div><Avatar size={24} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(28)</span></p>
          <div><Avatar size={28} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(36)</span></p>
          <div><Avatar size={36} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(40)</span></p>
          <div><Avatar size={40} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(44)</span></p>
          <div><Avatar size={44} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(52)</span></p>
          <div><Avatar size={52} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(72)</span></p>
          <div><Avatar size={72} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(80)</span></p>
          <div><Avatar size={80} title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">size=(84)</span></p>
          <div><Avatar size={84} title="Tom Smith"/></div>
        </div>
      </div>
    );
  }
}
**/

/**
* @name Types of Avatar
*
* @category communication
* @component avatar
* @section types
*
* @js
*

 export default class AvatarTypes extends React.PureComponent {
  render() {
    return (
      <div className='row'>
        <div className="example-spacing">
          <p><span className="h3">default</span></p>
          <div><Avatar title="Tom Smith"/></div>
          <br></br>

          <p><span className="h3">active</span></p>
          <div><Avatar title="Tom Smith" type="active"/></div>
          <br></br>

          <p><span className="h3">Do not disturb</span></p>
          <div><Avatar title="Tom Smith" type="dnd"/></div>
          <br></br>

          <p><span className="h3">Out of office</span></p>
          <div><Avatar title="Tom Smith" type="ooo"/></div>
          <br></br>

          <p><span className="h3">Group</span></p>
          <div><Avatar title="Tom Smith" type="group"/></div>
          <br></br>

          <p><span className="h3">Bot</span></p>
          <div><Avatar title="Tom Smith" type="bot"/></div>
          <br></br>

          <p><span className="h3">FailureBadge</span></p>
          <div><Avatar title="Tom Smith" failureBadge={true}/></div>
          <br></br>

          <p><span className="h3">Typing</span></p>
          <div><Avatar title="Tom Smith" type="typing"/></div>
          <br></br>

          <p><span className="h3">Inactive</span></p>
          <div><Avatar title="Tom Smith" type="inactive"/></div>
        </div>
      </div>
    );
  }
}
**/

/**
* @name Avatar with different contents
*
* @category communication
* @component avatar
* @section contents
*
* @js
*
 import { Icon } from '@collab-ui/react';
 import libraryIcon from '@collab-ui/core/docs/assets/react.png';

 export default class AvatarContents extends React.PureComponent {
  render() {
    return (
      <div className='row'>
        <div className="example-spacing">
          <p><span className="h3">With image</span></p>
          <div><Avatar title="React" src={libraryIcon}/></div>
          <br></br>

          <p><span className="h3">With icon</span></p>
          <div><Avatar title="Feedback" icon={<Icon name="feedback_16"/>}/></div>
          <br></br>

          <p><span className="h3">With title</span></p>
          <div><Avatar title="Tom Smith"/></div>
          <br></br>
        </div>
      </div>
    );
  }
}
**/

/**
* @name Composite avatars
*
* @category communication
* @component avatar
* @section composite
*
* @js
*
 import { CompositeAvatar } from '@collab-ui/react';

 export default class CompositeAvatarExample extends React.PureComponent {
  render() {
    return (
      <div className='row'>
        <div className="example-spacing">
          <p><span className="h3">medium(Default Size)</span></p>
          <div>
          <CompositeAvatar>
            <Avatar title="Tom Smith"/>
            <Avatar title="John William"/>
          </CompositeAvatar>
          </div>
          <br></br>

          <p><span className="h3">small</span></p>
          <div>
            <CompositeAvatar size="small">
              <Avatar title="Tom Smith"/>
              <Avatar title="John William"/>
            </CompositeAvatar>
          </div>
          <br></br>

          <p><span className="h3">large</span></p>
          <div>
            <CompositeAvatar size="large">
              <Avatar title="Tom Smith"/>
              <Avatar title="John William"/>
            </CompositeAvatar>
          </div>
        </div>
      </div>
    );
  }
}
**/