"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _IsVisible = _interopRequireDefault(require("../IsVisible"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

/**
 * Dropdown is component for rendering dropdown menu
 * @param props
 * @returns {XML}
 * @constructor
 */
var Dropdown =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Dropdown, _React$Component);

  function Dropdown() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      selected: [],
      isOpen: false
    }, _this.getChildContext = function () {
      return {
        isOpen: _this.state.isOpen,
        selected: _this.state.selected
      };
    }, _this.toggleOpen = function () {
      var nextOpenState = !_this.state.isOpen;

      _this.setState({
        isOpen: nextOpenState
      });
    }, _this.handleClick = function (e, value) {
      var node = _reactDom.default.findDOMNode(_assertThisInitialized(_assertThisInitialized(_this)));

      var target = e.target;

      if (e.button === 2) {
        return e.stopPropagation();
      }

      var selected = _this.state.selected;
      var isActive = selected.includes(value);

      if (!node.contains(target) || target.nodeName === 'A') {
        _this.setState({
          isOpen: false
        });
      }

      if (isActive) return;

      if (isActive) {
        _this.setState({
          selected: selected.filter(function (v) {
            return v !== value;
          })
        });
      } else if (!isActive) {
        _this.setState({
          selected: [value]
        });
      } else {
        _this.setState({
          selected: selected.concat([value])
        });
      }
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = Dropdown.prototype;

  _proto.componentWillUpdate = function componentWillUpdate(nextProps, nextState) {
    if (this.state.isOpen === nextState.isOpen) {
      return;
    }

    if (nextState.isOpen) {
      window.addEventListener('click', this.handleClick);
    } else {
      window.removeEventListener('click', this.handleClick);
    }
  };

  _proto.render = function render() {
    var _this2 = this;

    var children = this.props.children;
    var isOpen = this.state.isOpen;

    var renderChildren = function renderChildren() {
      return _react.default.Children.map(children, function (child) {
        if (child.props.type === 'button') {
          return _react.default.cloneElement(child, {
            onClick: function onClick() {
              return _this2.toggleOpen();
            },
            className: "top-bar__user cui-dropdown-toggle dropdown-toggle"
          });
        } else if (child.type.displayName === 'List') {
          return _react.default.createElement(_IsVisible.default, {
            isOpen: isOpen
          }, _react.default.cloneElement(child, {
            className: "dropdown-menu"
          }));
        }

        return child;
      });
    };

    return _react.default.createElement("div", {
      "cui-dropdown": "cui-dropdown",
      className: 'cui-dropdown' + ("" + (isOpen && ' open' || ''))
    }, renderChildren());
  };

  return Dropdown;
}(_react.default.Component);

exports.default = Dropdown;
Dropdown.displayName = 'Dropdown';
Dropdown.childContextTypes = {
  /** Whether menu isOpen or not. */
  isOpen: _propTypes.default.bool,

  /** OnClick function for button. */
  onClick: _propTypes.default.func,

  /** Array/Object of Selected items. */
  selected: _propTypes.default.any
};
Dropdown.defaultProps = {
  onClick: null,
  selected: null,
  isOpen: false,
  children: null
};
Dropdown.propTypes = {
  /** Child component to display next to the input */
  children: _propTypes.default.node
};